==> aws-java-sdk-ses-1.10.37-sources.jar: com/amazonaws/services/simpleemail/model/transform/WorkmailActionStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleemail.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.simpleemail.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Workmail Action StAX Unmarshaller
 */
public class WorkmailActionStaxUnmarshaller implements Unmarshaller<WorkmailAction, StaxUnmarshallerContext> {

    public WorkmailAction unmarshall(StaxUnmarshallerContext context) throws Exception {
        WorkmailAction workmailAction = new WorkmailAction();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return workmailAction;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("TopicArn", targetDepth)) {
                    workmailAction.setTopicArn(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("OrganizationArn", targetDepth)) {
                    workmailAction.setOrganizationArn(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return workmailAction;
                }
            }
        }
    }

    private static WorkmailActionStaxUnmarshaller instance;
    public static WorkmailActionStaxUnmarshaller getInstance() {
        if (instance == null) instance = new WorkmailActionStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-ses-1.10.46-sources.jar: com/amazonaws/services/simpleemail/model/transform/WorkmailActionStaxUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleemail.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.simpleemail.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * WorkmailAction StAX Unmarshaller
 */
public class WorkmailActionStaxUnmarshaller implements
        Unmarshaller<WorkmailAction, StaxUnmarshallerContext> {

    public WorkmailAction unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        WorkmailAction workmailAction = new WorkmailAction();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return workmailAction;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("TopicArn", targetDepth)) {
                    workmailAction.setTopicArn(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("OrganizationArn", targetDepth)) {
                    workmailAction.setOrganizationArn(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return workmailAction;
                }
            }
        }
    }

    private static WorkmailActionStaxUnmarshaller instance;

    public static WorkmailActionStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new WorkmailActionStaxUnmarshaller();
        return instance;
    }
}
